.. image:: https://img.shields.io/pypi/v/bioblend.svg
    :target: https://pypi.python.org/pypi/bioblend/
    :alt: latest version available on PyPI

.. image:: https://img.shields.io/pypi/dm/bioblend.svg
    :target: https://pypi.python.org/pypi/bioblend/
    :alt: PyPI downloads in the last month

.. image:: https://readthedocs.org/projects/bioblend/badge/
    :alt: Documentation Status
    :target: https://bioblend.readthedocs.org/

.. image:: https://travis-ci.org/galaxyproject/bioblend.png
    :target: https://travis-ci.org/galaxyproject/bioblend
    :alt: Build Status

.. image:: https://landscape.io/github/galaxyproject/bioblend/master/landscape.svg?style=flat
    :target: https://landscape.io/github/galaxyproject/bioblend/master
    :alt: Code Health


BioBlend is a Python library for interacting with `CloudMan`_ and `Galaxy`_'s
API.

BioBlend is supported and tested on:

- Python 2.6 and 2.7 (Python 3.3 and 3.4 have been added in the unreleased master branch)
- Galaxy release_14.02 and later.

Full docs are available at http://bioblend.readthedocs.org with a quick library
overview also available in `ABOUT.rst <./ABOUT.rst>`_.

.. References/hyperlinks used above
.. _CloudMan: http://usecloudman.org/
.. _Galaxy: http://usegalaxy.org/
